@@ -21,5 +21,5 @@ rm -f ns1/named.conf ns1/myftp.db
 rm -f ns3/*.jnl ns3/mytest.db ns3/subtest.db
 rm -f ns4/*.jnl ns4/*.db
 rm -f */named.memstats
-rm -f dig.out
+rm -f dig.out dig.out1 dig.out2 dig.out3
 rm -f ns3/large.db
