@@ -1,6 +1,6 @@
 #!/bin/sh
 #
-# Copyright (C) 2005, 2007, 2011-2013  Internet Systems Consortium, Inc. ("ISC")
+# Copyright (C) 2005, 2007, 2011-2014  Internet Systems Consortium, Inc. ("ISC")
 #
 # Permission to use, copy, modify, and/or distribute this software for any
 # purpose with or without fee is hereby granted, provided that the above
@@ -20,7 +20,7 @@ SYSTEMTESTTOP=..
 . $SYSTEMTESTTOP/conf.sh
 
 ismap () {
-    perl -e 'binmode STDIN;
+    $PERL -e 'binmode STDIN;
 	     read(STDIN, $input, 8);
              ($style, $version) = unpack("NN", $input);
              exit 1 if ($style != 3 || $version > 1);' < $1
@@ -28,7 +28,7 @@ ismap () {
 }
 
 israw () {
-    perl -e 'binmode STDIN;
+    $PERL -e 'binmode STDIN;
              read(STDIN, $input, 8);
              ($style, $version) = unpack("NN", $input);
              exit 1 if ($style != 2 || $version > 1);' < $1
@@ -36,7 +36,7 @@ israw () {
 }
 
 rawversion () {
-    perl -e 'binmode STDIN;
+    $PERL -e 'binmode STDIN;
              read(STDIN, $input, 8);
              if (length($input) < 8) { print "not raw\n"; exit 0; };
              ($style, $version) = unpack("NN", $input);
@@ -45,7 +45,7 @@ rawversion () {
 }
 
 sourceserial () {
-    perl -e 'binmode STDIN;
+    $PERL -e 'binmode STDIN;
              read(STDIN, $input, 20);
              if (length($input) < 20) { print "UNSET\n"; exit; };
              ($format, $version, $dumptime, $flags, $sourceserial) = 
@@ -59,7 +59,7 @@ sourceserial () {
 }
 
 stomp () {
-        perl -e 'open(my $file, "+<", $ARGV[0]);
+        $PERL -e 'open(my $file, "+<", $ARGV[0]);
                  binmode $file;
                  seek($file, $ARGV[1], 0);
                  for (my $i = 0; $i < $ARGV[2]; $i++) {
@@ -82,7 +82,8 @@ ret=0
 set -- 1 2 3
 for zone in example example-explicit example-compat; do
     for server in $*; do
-	for name in ns mx a aaaa cname dname txt rrsig nsec dnskey ds; do
+	for name in ns mx a aaaa cname dname txt rrsig nsec \
+		    dnskey ds cdnskey cds; do
 		$DIG $DIGOPTS $name.$zone. $name @10.53.0.$server -p 5300
 		echo
 	done > dig.out.$zone.$server
